package MT::Plugin::SKR::HiddenEntries;
# HiddenEntries - Enable you to create a hidden entry/webpage in entry list.
#       Copyright (c) 2008 Skyarc System Co.,Ltd.
#       http://www.skyarc.co.jp/

use strict;
use MT;
use MT::Template::Context;
use MT::SKR::HiddenEntries::Hidden;

use vars qw( $MYNAME $VERSION $SCHEMA_VERSION );
$MYNAME = 'HiddenEntries';
$VERSION = '1.03';

$SCHEMA_VERSION = '0.004';

use base qw( MT::Plugin );
my $plugin = __PACKAGE__->new({
        name => $MYNAME,
        version => $VERSION,
        key => lc $MYNAME,
        id => lc $MYNAME,
        author_name => q{ SKYARC System Co.,Ltd. },
        author_link => q{ http://www.skyarc.co.jp/ },
        doc_link => qw{ http://www.skyarc.co.jp/ },
        l10n_class => 'SKR::HiddenEntries::L10N',
        description => '<MT_TRANS phrase="Enable you to create a hidden entry/webpage in entry list.">',
        schema_version => $SCHEMA_VERSION,
});
MT->add_plugin( $plugin );


sub instance { $plugin; }



### Registry
sub init_registry { 
    my $plugin = shift;
    $plugin->registry({
        tags => {
             block => {
                  VisiblePages   => 'SKR::HiddenEntries::Tags::entries_publish_limiter_multiblog_bridge',
                  VisibleEntries => 'SKR::HiddenEntries::Tags::entries_publish_limiter_multiblog_bridge',
             },
        },
        object_types => {
            'eplimiter' => 'MT::SKR::HiddenEntries::Hidden',
        },
    });
}

### Regist callbacks
MT->add_callback( 'MT::App::CMS::template_source.edit_entry', 9, $plugin, \&_source_edit_entry );
MT->add_callback( 'MT::App::CMS::template_param.edit_entry' , 9, $plugin, \&_param_edit_entry );
MT->add_callback( 'CMSPostSave.page'  , 9 , $plugin, \&cms_post_save );
MT->add_callback( 'CMSPostSave.entry' , 9 , $plugin, \&cms_post_save );



### eʂ̃ev[gJX^}CY
sub _source_edit_entry {
    my ($eh, $app, $tmpl_ref, $tmpl_filename) = @_;

    my $old = quotemeta( <<'HTML' );
        <mt:if name="status_future">
HTML
    my $label_title = $plugin->translate( 'Visibility in list' );
    my $label_checkbox = $plugin->translate( 'Hidden' );
    my $new = <<"HTML";
        <mtapp:setting
           id="entry_publish_limit"
           label="$label_title"
           help_page=""
           help_section="">
           <input type="checkbox" name="entry_publish_limit" id="entry_publish_limit" tabindex="14" value="1"<mt:if name="entry_publish_limit"> checked="checked"</mt:if> />
           <label for="entry_publish_limit">$label_checkbox</label>
        </mtapp:setting>
HTML
    $$tmpl_ref =~ s/($old)/$new$1/;
}

### eʂ̃p[^JX^}CY
sub _param_edit_entry {
    my ($eh, $app, $param_ref, $tmpl_ref) = @_;

    $param_ref->{'entry_publish_limit'} = 0;

    #uOhcƃy[WhcŃ`FbN(VK̏ꍇ0)
    my $page_id = $app->{query}->param( 'id' );
    if ($page_id) {
        my $blog_id = $app->{query}->param( 'blog_id' );
        my $limit = MT::SKR::HiddenEntries::Hidden->load({ blog_id => $blog_id, entry_id => $page_id });
        if ($limit) {
            $param_ref->{'entry_publish_limit'} = 1;
        }
    }
}



### GgEEFuy[Wۑ̃R[obNBݒ擾͕ێȂB
sub cms_post_save {
    my ($eh, $app, $obj, $original) = @_;

    my $sflag = $app->param( 'entry_publish_limit' ) || 0;

    my $blog_id = $obj->blog_id;
    my $eid = $obj->id;
    my $limit = MT::SKR::HiddenEntries::Hidden->load({ blog_id => $blog_id, entry_id => $eid });
    if ($limit && !$sflag) {
        $limit->remove;
    }
    elsif (!$limit && $sflag) {
        $limit = new MT::SKR::HiddenEntries::Hidden;
        $limit->blog_id( $blog_id );
        $limit->entry_id( $eid );
        $limit->condition( 1 ); # meaningless in fact
        $limit->save;
    }
}



#
#   ɂ
#
#    ݂͎蓮ŃXCb`ւ@̂ݎALAEFuy[WeʂŌJɃ`FbN邱Ƃ
#    pɗpӂ^Oɂo͂𐧌邱ƂłB
#    pӂ^O͊EntriesPagesl̋@\Ă邪ɂĂ͋@\Ȃ̂邩ȂB
#
#   Limiter.pm͐ێB̂ݕۑB
#
#    mt_eplimiter.id 
#    mt_eplimiter.entry_id
#    mt_eplimiter.blog_id
#    mt_eplimiter.condition  : 1̂Ƃŕ\Ȃ 2ȍ~͊gpŏƂ̂ݕ\Ȃ
#
#    condition=1ȊO͊gp̃e[uɐݒ肳ꂽB
#
#    ꍇ 2 , 3 , 4ꂼɎ̐ݒ肵A̎𖞂ԍ1Ƃ킹
#    Limiter[h悤ɂB
#

# 2008.06.02 update version 1.01 MultiBlogɑΉ
#
#    <MTEntries>̋@\ɌJtB^[ǉ<MTEntriesPublishLimiter>𗘗po͂𓊍eʂŐ䂷
#    <MTPages>̏ꍇ<MTPagesPublishLimiter>𗘗p
#
#    Limiter.pm mt_eplimiter.condition̉߂ύX
#    0̂ƂXCb`̐Ƃ



1;